Module prelude

Module prelude 

预导入模块

Re-exports

pub use crate::QueueConfig;
pub use crate::QueueType;

Structs

BaseQueue
队列基类
Job
任务信息
JobOptions
任务选项
Queue
队列
Scheduler
定时任务调度器
Worker
Worker

Enums

JobStatus
任务状态

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
JobHandler
任务处理器 trait
Serialize
A data structure that can be serialized into any data format supported by Serde.

Type Aliases

JobResult
任务结果

Attribute Macros

async_trait

Derive Macros

Deserialize
Serialize