预导入模块
Re-exports
pub use crate::QueueConfig;pub use crate::QueueType;
Structs
Enums
- JobStatus
- 任务状态
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- JobHandler
- 任务处理器 trait
- Serialize
- A data structure that can be serialized into any data format supported by Serde.
Type Aliases
- JobResult
- 任务结果